
# Slot: owner _(deprecated)_


the "owner" of the slot. It is the class if it appears in the slots list, otherwise the declaring slot

URI: [linkml:owner](https://w3id.org/linkml/owner)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Definition](Definition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
